<?php

  /*
   * Cette classe decrit un plugin "vide" et peut servir de base
   * au developpement d'un nouveau plugin.
   *
   *
   * pour creer un nouveau plugin (par exemple "mon_plugin") :
   *
   *  - creez un dossier "mon_plugin" dans le dossier "mw/plugins"
   *
   *  - copiez dans ce dossier le fichier "mw_minimal.php" et renommez-le
   *    en "mon_plugin.php"
   *
   *  - dans "mon_plugin.php", renommez la classe en :
   *
   *   class mon_plugin extends mw_plugin
   *
   * vous aurez alors un nouveau plugin, activable dans l'administration
   * du site.
   *
   *
   * Votre dossier de plugin mw/plugins/mon_plugin peut contenir
   * un dossier app avec les sous-dossiers :
   *
   *  - app/controllers
   *  - app/data
   *  - app/out
   *  - app/observers
   *  - ...
   *
   * ces dossiers seront traites de le meme facon que ceux de
   * l'application principale (dans le dossier mw/app)
   * plus d'infos sur ce dossier app dans la doc en ligne :
   *
   * http://mtweb.dj3c1t.com/index.php?id=14&e=pages/view/page#mvc
   *
   */

  class mw_minimal extends mw_plugin{

    /*
     * retourne une chaine de caracteres avec le nom du plugin
     * tel qu'il apparaitra dans l'administration du site
     *
     */
    public function title(){
      return "Minimal";
    }

    /*
     * retourne une chaine de caracteres avec la description du plugin
     * telle qu'elle apparaitra dans l'administration du site
     *
     */
    public function description(){
      return "Un plugin 'vide'";
    }

    /*
     * Cette methode sera appelee a chaque requete, avant la methode "init"
     * (voir plus bas), que le plugin soit activé ou pas dans l'administration
     * du site.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     */
    public function loaded($env){
    }

    /*
     * Cette methode sera appelee a chaque requete, si le plugin
     * est installé ET activé
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - TRUE en cas de succes
     * - FALSE en cas d'erreur
     *
     * Si la methode retourne TRUE, l'application principale continuera
     * son traitement normalement
     *
     * Si la methode retourne FALSE, l'application principale sera terminée,
     * la requète ne sera pas traitée et un message d'erreur indiquera qu'une
     * erreur s'est produite durant l'initialisation du plugin.
     *
     */
    public function init($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "installer"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    public function install($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "desinstaller"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    public function uninstall($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "activer"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    public function enable($env){
      return true;
    }

    /*
     * Cette methode sera appelee lors du clic sur le lien "desctiver"
     * dans l'administration, pour ce plugin.
     * 
     * l'objet $env est fourni en parametre par l'application au moment
     * de l'appel.
     *
     * retourne :
     * - une chaine de caracteres avec un message d'erreur en cas d'erreur
     * - TRUE en cas de succes
     *
     */
    public function disable($env){
      return true;
    }

  }
